Learn R Programming

puremoe (version 1.0.3)

search_pubmed: Search 'PubMed' Records

Description

Performs a 'PubMed' search based on a query, optionally filtered by publication years. Returns a unique set of 'PubMed' IDs matching the query.

Usage

search_pubmed(
  x,
  start_year = NULL,
  end_year = NULL,
  retmax = 9999,
  use_pub_years = FALSE
)

Value

Numeric vector of unique PubMed IDs.

Arguments

x

Character string, the search query.

start_year

Integer, the start year of publication date range (used if `use_pub_years` is TRUE).

end_year

Integer, the end year of publication date range (used if `use_pub_years` is TRUE).

retmax

Integer, maximum number of records to retrieve, defaults to 9999.

use_pub_years

Logical, whether to filter search by publication years, defaults to TRUE.

Examples

Run this code
ethnob1 <- search_pubmed("ethnobotany", 2010, 2012)


Run the code above in your browser using DataLab