powered by
Performs a 'PubMed' search based on a query, optionally filtered by publication years. Returns a unique set of 'PubMed' IDs matching the query.
search_pubmed( x, start_year = NULL, end_year = NULL, retmax = 9999, use_pub_years = FALSE )
Numeric vector of unique PubMed IDs.
Character string, the search query.
Integer, the start year of publication date range (used if `use_pub_years` is TRUE).
Integer, the end year of publication date range (used if `use_pub_years` is TRUE).
Integer, maximum number of records to retrieve, defaults to 9999.
Logical, whether to filter search by publication years, defaults to TRUE.
ethnob1 <- search_pubmed("ethnobotany", 2010, 2012)
Run the code above in your browser using DataLab